==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/calculel/meriro.f <==
      SUBROUTINE MERIRO(MODELE,NCHAR,LCHAR,MATE,EXITIM,TIME,MATEL)
      IMPLICIT REAL*8 (A-H,O-Z)

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF CALCULEL  DATE 11/09/2002   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================

C     ARGUMENTS:
C     ----------
      CHARACTER*8 MODELE,LCHAR(*),MATEL
      CHARACTER*24 MATE
      REAL*8 TIME
      LOGICAL EXITIM,EXITRO
      INTEGER NCHAR
C ----------------------------------------------------------------------

C     CALCUL DES MATRICES ELEMENTAIRES DE RAIDEUR CENTRIFUGE

C     ENTREES:

C     LES NOMS QUI SUIVENT SONT LES PREFIXES UTILISATEUR K8:
C        MODELE : NOM DU MODELE
C        NCHAR  : NOMBRE DE CHARGES
C        LCHAR  : LISTE DES CHARGES
C        MATE   : CHAMP DE MATERIAUX
C        EXITIM : VRAI SI L'INSTANT EST DONNE
C        TIME   : INSTANT DE CALCUL

C     SORTIES:

C        MATEL  : NOM DU MATEL (N RESUELEM) PRODUIT

C ----------------------------------------------------------------------

C     FONCTIONS EXTERNES:
C     -------------------
      CHARACTER*32 JEXNUM,JEXNOM,JEXATR

C     VARIABLES LOCALES:
C     ------------------
C---------------- COMMUNS NORMALISES  JEVEUX  --------------------------
      COMMON /IVARJE/ZI(1)
      COMMON /RVARJE/ZR(1)
      COMMON /CVARJE/ZC(1)
      COMMON /LVARJE/ZL(1)
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
      INTEGER ZI
      REAL*8 ZR
      COMPLEX*16 ZC
      LOGICAL ZL,EXIGEO,EXICAR,EXITHE
      CHARACTER*8 ZK8,LPAIN(10),LPAOUT(1),TEMPE,REPK
      CHARACTER*16 ZK16,OPTION
      CHARACTER*24 ZK24
      CHARACTER*24 CHGEOM,CHROTA,CHTEMP,LCHIN(10),LCHOUT(10)
      CHARACTER*24 LIGRMO
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80


C     -- ON VERIFIE LA PRESENCE PARFOIS NECESSAIRE DE CHAM_MATER

      CALL JEMARQ()
      IF (MODELE(1:1).EQ.' ') THEN
        CALL UTMESS('F','MERIRO','IL FAUT UN MODELE')
      END IF

      CALL MEGEOM(MODELE,LCHAR(1),EXIGEO,CHGEOM)

      EXITRO = .FALSE.
      DO 10 ICHA = 1,NCHAR
        CALL EXISD('CHAMP_GD',LCHAR(ICHA)//'.CHME.ROTAT',IRET)
        IF (IRET.NE.0) THEN
          CHROTA = LCHAR(ICHA)//'.CHME.ROTAT.DESC'
          EXITRO = .TRUE.
        END IF
   10 CONTINUE

      IF (.NOT.EXITRO) THEN
        CALL UTMESS('F','MERIRO','IL N''Y A PAS DE CHARGEMENT ROTATION '
     &              //'! LE CALCUL EST IMPOSSIBLE ')
      END IF

      TEMPE = ' '
      DO 20 ICHA = 1,NCHAR
        CALL JEEXIN(LCHAR(ICHA)//'.CHME.TEMPE.TEMP',IRET)
        IF (IRET.NE.0) THEN
          CALL JEVEUO(LCHAR(ICHA)//'.CHME.TEMPE.TEMP','L',JTEMP)
          TEMPE = ZK8(JTEMP)
        END IF
   20 CONTINUE

      CHTEMP = '&&MERIRO.CH_TEMP_R         '
      CALL METEMP(CHGEOM(1:8),TEMPE,EXITIM,TIME,' ',EXITHE,CHTEMP(1:19))
      CALL DISMOI('F','ELAS_F_TEMP',MATE,'CHAM_MATER',IBID,REPK,IERD)
      IF (REPK.EQ.'OUI') THEN
        IF (.NOT.EXITHE) THEN
          CALL UTMESS('F','MERIRO',
     &                'LE MATERIAU DEPEND DE LA TEMPERATURE'//
     &                '! IL N''Y A PAS DE CHAMP DE TEMPERATURE '//
     &                '! LE CALCUL EST IMPOSSIBLE ')
        END IF
      END IF

      CALL JEEXIN(MATEL//'.REFE_RESU',IRET)
      IF (IRET.GT.0) THEN
        CALL JEDETR(MATEL//'.REFE_RESU')
        CALL JEDETR(MATEL//'.LISTE_RESU')
      END IF
      CALL MEMARE('G',MATEL,MODELE,MATE,' ','RIGI_ROTA')
      CALL JECREO(MATEL//'.LISTE_RESU','G V K24')
      CALL JEECRA(MATEL//'.LISTE_RESU','LONMAX',1,' ')
      CALL JEVEUO(MATEL//'.LISTE_RESU','E',JLIRES)

      LPAOUT(1) = 'PMATUUR'
      LCHOUT(1) = MATEL//'.ME001'
      ILIRES = 0

      IF (MODELE.NE.'       ') THEN
        LPAIN(1) = 'PGEOMER'
        LCHIN(1) = CHGEOM
        LPAIN(2) = 'PMATERC'
        LCHIN(2) = MATE
        LPAIN(3) = 'PROTATR'
        LCHIN(3) = CHROTA
        LPAIN(4) = 'PTEMPER'
        LCHIN(4) = CHTEMP
        LIGRMO = MODELE//'.MODELE'
        OPTION = 'RIGI_MECA_RO'

        CALL CALCUL('S',OPTION,LIGRMO,4,LCHIN,LPAIN,1,LCHOUT,LPAOUT,'G')

        CALL EXISD('CHAMP_GD',LCHOUT(1) (1:19),IRET)
        IF (IRET.NE.0) THEN
          ILIRES = ILIRES + 1
          ZK24(JLIRES-1+ILIRES) = LCHOUT(1)
          CALL JEECRA(MATEL//'.LISTE_RESU','LONUTI',ILIRES,' ')
        END IF
      END IF

   30 CONTINUE
      CALL DETRSD('CHAMP_GD',CHTEMP)
      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/calculel/meriro.f <==
      SUBROUTINE MERIRO(MODELE,NCHAR,LCHAR,MATE,EXITIM,TIME,MATEL)
      IMPLICIT REAL*8 (A-H,O-Z)

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF CALCULEL  DATE 28/01/2005   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================

C     ARGUMENTS:
C     ----------
      CHARACTER*8 MODELE,LCHAR(*),MATEL
      CHARACTER*24 MATE
      REAL*8 TIME
      LOGICAL EXITIM
      INTEGER NCHAR
C ----------------------------------------------------------------------

C     CALCUL DES MATRICES ELEMENTAIRES DE RAIDEUR CENTRIFUGE

C     ENTREES:

C     LES NOMS QUI SUIVENT SONT LES PREFIXES UTILISATEUR K8:
C        MODELE : NOM DU MODELE
C        NCHAR  : NOMBRE DE CHARGES
C        LCHAR  : LISTE DES CHARGES
C        MATE   : CHAMP DE MATERIAUX
C        EXITIM : VRAI SI L'INSTANT EST DONNE
C        TIME   : INSTANT DE CALCUL

C     SORTIES:

C        MATEL  : NOM DU MATEL (N RESUELEM) PRODUIT

C ----------------------------------------------------------------------

C     FONCTIONS EXTERNES:
C     -------------------
      CHARACTER*32 JEXNUM,JEXNOM,JEXATR

C     VARIABLES LOCALES:
C     ------------------
C---------------- COMMUNS NORMALISES  JEVEUX  --------------------------
      COMMON /IVARJE/ZI(1)
      COMMON /RVARJE/ZR(1)
      COMMON /CVARJE/ZC(1)
      COMMON /LVARJE/ZL(1)
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
      INTEGER ZI
      REAL*8 ZR
      COMPLEX*16 ZC
      LOGICAL ZL,EXIGEO,EXICAR,EXITHE
      CHARACTER*8 ZK8,LPAIN(10),LPAOUT(1),TEMPE,REPK
      CHARACTER*16 ZK16,OPTION
      CHARACTER*24 ZK24
      CHARACTER*24 CHGEOM,CHROTA,CHTEMP,LCHIN(10),LCHOUT(10)
      CHARACTER*24 LIGRMO
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80


C     -- ON VERIFIE LA PRESENCE PARFOIS NECESSAIRE DE CHAM_MATER

      CALL JEMARQ()
      IF (MODELE(1:1).EQ.' ') THEN
        CALL UTMESS('F','MERIRO','IL FAUT UN MODELE')
      END IF

      CALL MEGEOM(MODELE,LCHAR(1),EXIGEO,CHGEOM)

      NBRO = 0
      DO 10 ICHA = 1,NCHAR
        CALL EXISD('CHAMP_GD',LCHAR(ICHA)//'.CHME.ROTAT',IRET)
        IF (IRET.NE.0) THEN
          CHROTA = LCHAR(ICHA)//'.CHME.ROTAT.DESC'
          NBRO = NBRO + 1
        END IF
   10 CONTINUE

      IF (NBRO.NE.1) THEN
        CALL UTMESS('F','MERIRO','IL FAUT 1 CHARGEMENT DE ROTATION '
     &              //'ET UN SEUL. ')
      END IF

      TEMPE = ' '
      DO 20 ICHA = 1,NCHAR
        CALL JEEXIN(LCHAR(ICHA)//'.CHME.TEMPE.TEMP',IRET)
        IF (IRET.NE.0) THEN
          CALL JEVEUO(LCHAR(ICHA)//'.CHME.TEMPE.TEMP','L',JTEMP)
          TEMPE = ZK8(JTEMP)
        END IF
   20 CONTINUE

      CHTEMP = '&&MERIRO.CH_TEMP_R         '
      CALL METEMP(CHGEOM(1:8),TEMPE,EXITIM,TIME,' ',EXITHE,CHTEMP(1:19))
      CALL DISMOI('F','ELAS_F_TEMP',MATE,'CHAM_MATER',IBID,REPK,IERD)
      IF (REPK.EQ.'OUI') THEN
        IF (.NOT.EXITHE) THEN
          CALL UTMESS('F','MERIRO',
     &                'LE MATERIAU DEPEND DE LA TEMPERATURE'//
     &                '! IL N''Y A PAS DE CHAMP DE TEMPERATURE '//
     &                '! LE CALCUL EST IMPOSSIBLE ')
        END IF
      END IF

      CALL JEEXIN(MATEL//'.REFE_RESU',IRET)
      IF (IRET.GT.0) THEN
        CALL JEDETR(MATEL//'.REFE_RESU')
        CALL JEDETR(MATEL//'.LISTE_RESU')
      END IF
      CALL MEMARE('G',MATEL,MODELE,MATE,' ','RIGI_ROTA')
      CALL JECREO(MATEL//'.LISTE_RESU','G V K24')
      CALL JEECRA(MATEL//'.LISTE_RESU','LONMAX',1,' ')
      CALL JEVEUO(MATEL//'.LISTE_RESU','E',JLIRES)

      LPAOUT(1) = 'PMATUUR'
      LCHOUT(1) = MATEL//'.ME001'
      ILIRES = 0

      IF (MODELE.NE.'       ') THEN
        LPAIN(1) = 'PGEOMER'
        LCHIN(1) = CHGEOM
        LPAIN(2) = 'PMATERC'
        LCHIN(2) = MATE
        LPAIN(3) = 'PROTATR'
        LCHIN(3) = CHROTA
        LPAIN(4) = 'PTEMPER'
        LCHIN(4) = CHTEMP
        LIGRMO = MODELE//'.MODELE'
        OPTION = 'RIGI_MECA_RO'

        CALL CALCUL('S',OPTION,LIGRMO,4,LCHIN,LPAIN,1,LCHOUT,LPAOUT,'G')

        CALL EXISD('CHAMP_GD',LCHOUT(1) (1:19),IRET)
        IF (IRET.NE.0) THEN
          ILIRES = ILIRES + 1
          ZK24(JLIRES-1+ILIRES) = LCHOUT(1)
          CALL JEECRA(MATEL//'.LISTE_RESU','LONUTI',ILIRES,' ')
        END IF
      END IF

   30 CONTINUE
      CALL DETRSD('CHAMP_GD',CHTEMP)
      CALL JEDEMA()
      END
